<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ko" sourcelanguage="en">
<context>
    <name>CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>%1 레벨을 벡터화 할 수 없음</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>프레임 없이 레벨을 벡터링 할 수 없음</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>%1 이미지를 벡터화 할 수 없음</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>잘못된 인수(%1): 이미지 또는 레벨이어야함</translation>
    </message>
</context>
<context>
    <name>FilePath</name>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation>절대 경로를 연결하세요: %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation>%1 디렉토리가 아님</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation>%1 디렉토리 읽기</translation>
    </message>
</context>
<context>
    <name>Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>%1 파일이 존재하지 않음</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation>%1 첫번째 프레임 가져오기</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation>이미지를 읽는 동안 이야기치 않는 오류 발생</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>인식 할 수 없는 파일 형식:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation>%1 이미지를 이 파일 형식에 저장할 수 있음: %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation>이미지를 쓰는 중 이야기치 않는 오류</translation>
    </message>
</context>
<context>
    <name>ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation>잘못된 인수(%1): 래스터 또는 툰즈 레스터 여야함</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation>이미지 빌더 (%1 이미지)</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation>잘못된 인수(%1): 변환이어야함</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>%1 frames</source>
        <translation>%1 프레임</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation>잘못된 인수(%1). 파일 경로 또는 문자열이어야함</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation>예외 적재 레벨(%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>%1 파일이 존재하지 않음</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation>%1 파일이 지원되지 않음</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>%1 읽기 예외</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation>빈 레벨을 저장할 수 없음</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>인식 할 수 없는 파일 형식:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation>%1 레벨을 이 파일 형식에 저장하세요: %2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>%1 쓰기 예외</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation>프레임 인덱스(%1)는 숫자여야함</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation>프레임 인덱스 (%1) 이 범위를 벗어남 (0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation>두 번? 인수(%1)는 이미지가 아님</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation>%1 이미지를 레벨에 삽입할 수 없음</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation>%1 이미지를 %2 레벨에 삽입할 수 없음</translation>
    </message>
</context>
<context>
    <name>OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>%1 레벨을 벡터화 할 수 없음</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>프레임 없이 레벨을 벡터링 할 수 없음</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>%1 이미지를 벡터화 할 수 없음</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>잘못된 인수(%1): 이미지 또는 레벨이어야함</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation>잘못된 색상 :</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <source>Retas Level Format</source>
        <translation>레스타 레벨 포맷</translation>
    </message>
    <message>
        <source>Adobe Photoshop</source>
        <translation>아도비 포토샵</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No restrictions for uncompressed avi video</source>
        <translation>압축되지 않은 avi 비디오에 대한 제한 없음</translation>
    </message>
    <message>
        <source>It is not possible to communicate with the codec.
 Probably the codec cannot work correctly.</source>
        <translation>코덱과 통신 할 수 없음.
코덱이 제대로 작동하지 않을 수 있음.</translation>
    </message>
    <message>
        <source>video width must be a multiple of %1</source>
        <translation>비디오 너비는 %1의 배수여야함</translation>
    </message>
    <message>
        <source>video length must be a multiple of %1</source>
        <translation>비디오 길이는 %1으 배수 여야함</translation>
    </message>
    <message>
        <source>No restrictions for this codec</source>
        <translation>이 코덱에는 제한이 없음</translation>
    </message>
    <message>
        <source>Resolution restrictions:</source>
        <translation>해상도 제한 :</translation>
    </message>
    <message>
        <source>New Camera  %1</source>
        <translation>새로운 카메라 %1</translation>
    </message>
    <message>
        <source>New Pegbar  %1</source>
        <translation>새로운 페그바 %1</translation>
    </message>
    <message>
        <source>Set Active Camera  %1 &gt; %2</source>
        <translation>활성 카메라 %1 &gt; %2 설정</translation>
    </message>
    <message>
        <source>Remove Spline  %1</source>
        <translation>스플라인 %1 제거</translation>
    </message>
    <message>
        <source>New Motion Path  %1</source>
        <translation>새로운 동작 경로 %1</translation>
    </message>
    <message>
        <source>Link Motion Path  %1 &gt; %2</source>
        <translation>링크 이동 경로 %1 &gt; %2</translation>
    </message>
    <message>
        <source>Remove Object  %1</source>
        <translation>%1 개체 제거</translation>
    </message>
    <message>
        <source>Remove Column  </source>
        <translation>열 제거</translation>
    </message>
    <message>
        <source>Load into Current Palette  &gt; %1</source>
        <translation>현재 팔레트에 가져오기  &gt; %1</translation>
    </message>
    <message>
        <source>Replace with Current Palette  &gt; %1</source>
        <translation>현재 팔레트로 교체  &gt; %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette  : %1</source>
        <translation>스튜디오 팔레트 삭제 : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette  : %1</source>
        <translation>스튜디오 팔레트 작성 : %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette Folder  : %1</source>
        <translation>스튜디오 팔레트 폴더 삭제 : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette Folder  : %1</source>
        <translation>스튜디오 팔레트 폴더 생성 : %1</translation>
    </message>
    <message>
        <source>Can&apos;t undo rename palette</source>
        <translation>팔레트 이름 바꾸기 실행 취소</translation>
    </message>
    <message>
        <source>Can&apos;t undo move palette</source>
        <translation>팔레트 이동 취소</translation>
    </message>
    <message>
        <source>Can&apos;t redo rename palette</source>
        <translation>팔레트 이름 바꾸기</translation>
    </message>
    <message>
        <source>Can&apos;t redo move palette</source>
        <translation>팔레트 이동 다시 실행</translation>
    </message>
    <message>
        <source>Rename Studio Palette : %1 &gt; %2</source>
        <translation>스튜디오 팔레트 이름 바꾸기 : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Move Studio Palette Folder  : %1 : %2 &gt; %3</source>
        <translation>스튜디오 팔레트 폴도 이동 : %1 : %2 &gt; %3</translation>
    </message>
    <message>
        <source>Arrange Styles  in Palette %1</source>
        <translation>팔레트 %1의 스타일 정렬</translation>
    </message>
    <message>
        <source>Create Style#%1  in Palette %2</source>
        <translation>팔레트 %2에서 스타일 # %1 생성</translation>
    </message>
    <message>
        <source>Add Style  to Palette %1</source>
        <translation>팔레트에 스타일 추가 %1</translation>
    </message>
    <message>
        <source>Add Page %1 to Palette %2</source>
        <translation>팔레트 %2에 %1 페이지 추가</translation>
    </message>
    <message>
        <source>Delete Page %1 from Palette %2</source>
        <translation>팔레트 %2 에서 %1 페이지 삭제</translation>
    </message>
    <message>
        <source>Load Color Model %1  to Palette %2</source>
        <translation>색상 모델 %1을 팔레트 %2에 가져오기</translation>
    </message>
    <message>
        <source>color model</source>
        <translation>색상 모델</translation>
    </message>
    <message>
        <source>Move Page</source>
        <translation>페이지 이동</translation>
    </message>
    <message>
        <source>Rename Page  %1 &gt; %2</source>
        <translation>페이지 이름 바꾸기 %1 &gt; %2</translation>
    </message>
    <message>
        <source>Rename Style#%1 in Palette%2  : %3 &gt; %4</source>
        <translation>팔레트 %2에서 스타일 이름바꾸기 #%1: %3 &gt; %4</translation>
    </message>
    <message>
        <source>Set Picked Position of Style#%1 in Palette%2 : %3,%4</source>
        <translation>팔레트 %2에서 선택한 스타일 #%1 위치설정: %3,%4</translation>
    </message>
    <message>
        <source>Update Colors by Using Picked Positions in Palette %1</source>
        <translation>팔레트 %1에서 선택한 위치를 사용하여 색상 업데이트</translation>
    </message>
    <message>
        <source>Add Fx  : </source>
        <translation>Fx 추가  : </translation>
    </message>
    <message>
        <source>Insert Fx  : </source>
        <translation>삽입 Fx :</translation>
    </message>
    <message>
        <source>Create Linked Fx  : %1</source>
        <translation>연결된 Fx 만들기 : %1</translation>
    </message>
    <message>
        <source>Replace Fx  : </source>
        <translation>Fx 교체 : </translation>
    </message>
    <message>
        <source>Unlink Fx  : %1 - - %2</source>
        <translation>연결 해제 Fx  : %1 - - %2</translation>
    </message>
    <message>
        <source>Make Macro Fx  : %1</source>
        <translation>매크로 Fx 만들기 : %1</translation>
    </message>
    <message>
        <source>Explode Macro Fx  : %1</source>
        <translation>매크로 Fx 분해: %1</translation>
    </message>
    <message>
        <source>Create Output Fx</source>
        <translation>출력 Fx 만들기</translation>
    </message>
    <message>
        <source>Connect to Xsheet  : </source>
        <translation>X시트 연결 : </translation>
    </message>
    <message>
        <source>Disconnect from Xsheet  : </source>
        <translation>X시트 연결 끊기 : </translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>링크 삭제</translation>
    </message>
    <message>
        <source>Delete Fx Node : %1</source>
        <translation>Fx 노드 삭제 : %1</translation>
    </message>
    <message>
        <source>Paste Fx  :  </source>
        <translation>Fx 붙여넣기 :</translation>
    </message>
    <message>
        <source>Disconnect Fx</source>
        <translation>Fx 연결끊기</translation>
    </message>
    <message>
        <source>Connect Fx : %1 - %2</source>
        <translation>연결 Fx : %1  - %2</translation>
    </message>
    <message>
        <source>Rename Fx : %1 &gt; %2</source>
        <translation>Fx 이름 바꾸기 : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Group Fx</source>
        <translation>Fx 그룹</translation>
    </message>
    <message>
        <source>Ungroup Fx</source>
        <translation>Fx 그룹해제</translation>
    </message>
    <message>
        <source>Rename Group  : %1 &gt; %2</source>
        <translation>그룹 이름 바꾸기 : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Set Keyframe</source>
        <translation>키 프레임 설정</translation>
    </message>
    <message>
        <source>Remove Keyframe</source>
        <translation>키 프레임 제거</translation>
    </message>
    <message>
        <source>Cycle</source>
        <translation>순환</translation>
    </message>
    <message>
        <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
        <translation>자동 그림판 옵션 팔레트 전환 : %1 스타일 #%2</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>빨강</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>녹색</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>파랑</translation>
    </message>
    <message>
        <source>DarkYellow</source>
        <translation>다크 옐로우</translation>
    </message>
    <message>
        <source>DarkCyan</source>
        <translation>다크 시안</translation>
    </message>
    <message>
        <source>DarkMagenta</source>
        <translation>다크 마젠타</translation>
    </message>
    <message>
        <source>The autocentering failed on the current drawing.</source>
        <translation>현재 도면에서 자동 입력 실패.</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>이동</translation>
    </message>
    <message>
        <source>Edit Rotation</source>
        <translation>회전 편집</translation>
    </message>
    <message>
        <source>Move X</source>
        <translation>X 이동</translation>
    </message>
    <message>
        <source>Move Y</source>
        <translation>Y 이동</translation>
    </message>
    <message>
        <source>Move Z</source>
        <translation>Z 이동</translation>
    </message>
    <message>
        <source>Edit Stack Order</source>
        <translation>스택 순서 편집</translation>
    </message>
    <message>
        <source>Edit Scale W</source>
        <translation>스케일 편집 W</translation>
    </message>
    <message>
        <source>Edit Scale H</source>
        <translation>스케일 H 편집</translation>
    </message>
    <message>
        <source>Edit Scale</source>
        <translation>스케일 편집</translation>
    </message>
    <message>
        <source>Edit PosPath</source>
        <translation>POS 경로편집</translation>
    </message>
    <message>
        <source>Edit Shear X</source>
        <translation>왜곡 X 편집</translation>
    </message>
    <message>
        <source>Edit Shear Y</source>
        <translation>왜곡 Y 편집</translation>
    </message>
    <message>
        <source>%1  %2  Frame : %3</source>
        <translation>%1  %2  프레임 : %3</translation>
    </message>
    <message>
        <source>First argument must be a scene : %1</source>
        <translation>첫 번째 인수는 장면이어야함 : %1</translation>
    </message>
    <message>
        <source>Can&apos;t render empty scene</source>
        <translation>빈 장면을 렌더링 할 수 있음</translation>
    </message>
    <message>
        <source>Vectorization failed</source>
        <translation>벡터화 실패</translation>
    </message>
    <message>
        <source>Argument &apos;%1&apos; does not look like a FrameId</source>
        <translation>인수 %1 Frameld 처럼 보이지 않음</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image (not empty)</source>
        <translation>잘못된 인수 (%1): 이미지여야함(비어있지 않아야함)</translation>
    </message>
    <message>
        <source>Argument doesn&apos;t look like a file path : %1</source>
        <translation>인수가 파일 경로처럼 보이지 않음 : %1</translation>
    </message>
    <message>
        <source>%1-%2</source>
        <translation></translation>
    </message>
    <message>
        <source>%1</source>
        <translation></translation>
    </message>
    <message>
        <source>Expected %1 argument(s) in %2, got %3</source>
        <translation>%2에서 예상된 %1 인수, %3을 얻음</translation>
    </message>
    <message>
        <source>%1 is not a valid color (valid color names are &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</source>
        <translation>%1은 유효한 색상이 아님(유효한 색상 이름은 &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</translation>
    </message>
    <message>
        <source>Can&apos;t save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation>명도</translation>
    </message>
    <message>
        <source>Contrast</source>
        <translation>차이</translation>
    </message>
    <message>
        <source>HRange</source>
        <translation>수평범위</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>선 폭</translation>
    </message>
    <message>
        <source>ColorThres</source>
        <translation>컬러 임계 값</translation>
    </message>
    <message>
        <source>WhiteThres</source>
        <translation>화이트 타이어</translation>
    </message>
    <message>
        <source>Xsheet</source>
        <translation>X-시트</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>타임라인</translation>
    </message>
    <message>
        <source>Set Keyframe   %1 at frame %2</source>
        <translation>%2 프레임에서 키프레임 %1 설정</translation>
    </message>
    <message>
        <source>Remove Keyframe   %1 at frame %2</source>
        <translation>프레임 %2에서 키프레임 %1을 제거하세요</translation>
    </message>
    <message>
        <source>Move Center   %1  Frame %2</source>
        <translation>센터 %1 프레임 %2 이동</translation>
    </message>
    <message>
        <source>Failed to save the following resources:
</source>
        <translation>다음 리소스 저장 실패:
</translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation>팔레트를 저장하지 못했습니다.</translation>
    </message>
    <message>
        <source>and %1 more item(s).</source>
        <translation>그리고 %1 더 많은 항목(s).</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>주황색</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>노란색</translation>
    </message>
    <message>
        <source>Light Green</source>
        <translation>라이트 그린</translation>
    </message>
    <message>
        <source>Light Blue</source>
        <translation>라이트 블루</translation>
    </message>
    <message>
        <source>Dark Blue</source>
        <translation>다크 블루</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>보라색</translation>
    </message>
    <message>
        <source>Pink</source>
        <translation>분홍색</translation>
    </message>
    <message>
        <source>Dark Pink</source>
        <translation>다크 핑크</translation>
    </message>
    <message>
        <source>White</source>
        <translation>화이트</translation>
    </message>
    <message>
        <source>Custom Texture</source>
        <comment>TextureStyleChooserPage</comment>
        <translation>사용자 지정 텍스처</translation>
    </message>
</context>
<context>
    <name>Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation>벡터 레벨 이미지: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation>벡터 레벨 예상: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation>인수는 벡터 레벨 또는 이미지여야함 :</translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation>팔레트가 없음 %1</translation>
    </message>
</context>
<context>
    <name>Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>%1 파일이 존재하지 않음</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>%1 읽기 예외</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>%1 쓰기 예외</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation>잘못된 레벨 유형(%1): 벡터, 래스터 또는 툰즈 래스터여야함</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation>레벨을 추가할 수 없음: 이름(%1)이 이미 사용됨</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation>이 종류의 파일을 레벨로 가져올 수 없음: %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation>%1 레벨을 가져올 수 없음</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation>레벨은 장면에 포함되어 있지 않음: %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation>%1: 예상되는 레벨 인스턴스 또는 레벨 이름 </translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation>레벨 %1 현장에 포함되지 않음</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>%1 레벨을 벡터화 할 수 없음</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>프레임 없이 레벨을 벡터링 할 수 없음</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>%1 이미지를 벡터화 할 수 없음</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>잘못된 인수(%1): 이미지 또는 레벨이어야함</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation></translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation>절대 경로를 연결하세요: %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation>%1 디렉토리가 아님</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation>%1 디렉토리 읽기</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>%1 파일이 존재하지 않음</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation>%1 첫번째 프레임 가져오기</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation>이미지를 읽는 동안 이야기치 않는 오류 발생</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>인식 할 수 없는 파일 형식:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation>%1 이미지를 이 파일 형식에 저장할 수 있음: %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation>이미지를 쓰는 중 이야기치 않는 오류</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation>잘못된 인수(%1): 래스터 또는 툰즈 레스터 여야함</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation>이미지 빌더 (%1 이미지)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation>잘못된 인수(%1): 변환이어야함</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Level</name>
    <message>
        <source>%1 frames</source>
        <translation>%1 프레임</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation>잘못된 인수(%1). 파일 경로 또는 문자열이어야함</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation>예외 적재 레벨(%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>%1 파일이 존재하지 않음</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation>%1 파일이 지원되지 않음</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>%1 읽기 예외</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation>빈 레벨을 저장할 수 없음</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>인식 할 수 없는 파일 형식:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation>%1 레벨을 이 파일 형식에 저장하세요: %2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>%1 쓰기 예외</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation>프레임 인덱스(%1)는 숫자여야함</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation>프레임 인덱스 (%1) 이 범위를 벗어남 (0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation>두 번? 인수(%1)는 이미지가 아님</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation>%1 이미지를 레벨에 삽입할 수 없음</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation>%1 이미지를 %2 레벨에 삽입할 수 없음</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>%1 레벨을 벡터화 할 수 없음</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>프레임 없이 레벨을 벡터링 할 수 없음</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>%1 이미지를 벡터화 할 수 없음</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>잘못된 인수(%1): 이미지 또는 레벨이어야함</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation>잘못된 색상 :</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation>벡터 레벨 이미지: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation>벡터 레벨 예상: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation>인수는 벡터 레벨 또는 이미지여야함 :</translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation>팔레트가 없음 %1</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>%1 파일이 존재하지 않음</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>%1 읽기 예외</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>%1 쓰기 예외</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation>잘못된 레벨 유형(%1): 벡터, 래스터 또는 툰즈 래스터여야함</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation>레벨을 추가할 수 없음: 이름(%1)이 이미 사용됨</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation>이 종류의 파일을 레벨로 가져올 수 없음: %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation>%1 레벨을 가져올 수 없음</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation>레벨은 장면에 포함되어 있지 않음: %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation>%1: 예상되는 레벨 인스턴스 또는 레벨 이름 </translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation>레벨 %1 현장에 포함되지 않음</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation>%1 레벨을 변환할 수 있음</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation>프레임 없이 레벨을 변환 할수 있음</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation>%1 이미지를 변환할 수 있음</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation>잘못된 인수(%1): 래스터 레벨 또는 래스터 이미지여야함</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Transform</name>
    <message>
        <source>Identity</source>
        <translation>정체</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation>번역(%1,%2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation>회전(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation>비율(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation>비율(%1%, %2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation>변환(%1, %2, %3, %4, %5, %6)</translation>
    </message>
</context>
<context>
    <name>ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation>%1 레벨을 변환할 수 있음</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation>프레임 없이 레벨을 변환 할수 있음</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation>%1 이미지를 변환할 수 있음</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation>잘못된 인수(%1): 래스터 레벨 또는 래스터 이미지여야함</translation>
    </message>
</context>
<context>
    <name>Transform</name>
    <message>
        <source>Identity</source>
        <translation>정체</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation>번역(%1,%2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation>회전(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation>비율(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation>비율(%1%, %2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation>변환(%1, %2, %3, %4, %5, %6)</translation>
    </message>
</context>
</TS>
